# Welcome to geojp
![](https://oyster.ignimgs.com/wordpress/stg.ign.com/2013/04/JurassicPark_040413_1600.jpg?width=1920)


[![image](https://img.shields.io/pypi/v/geojp.svg)](https://pypi.python.org/pypi/geojp)
[![image](https://img.shields.io/conda/vn/conda-forge/geojp.svg)](https://anaconda.org/conda-forge/geojp)



**A python package for my Geospacial Analysis class**


-   Free software: MIT License
-   Documentation: https://BrycenHarris.github.io/geojp
    

## Features
[![image](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/drive/1ACdkkGf42pxVr_FYClmFkHEVHVkgtMlu#scrollTo=iyQ_0vYVtNwV)
-   Generate random numbers